@@ -1,11 +1,9 @@
 """Git utils for Stackler"""
 
 import os
-import sys
 
 from typing import Optional
 from git import Commit, GitCommandError, Repo
-from stackler import display_utils
 
 REPO_PATH = os.getcwd()
 BASE_TAG = "origin/develop"
