@@ -143,7 +143,7 @@ def _submit(base: str,
                 subprocess.run(arc_args, check=True)
             except subprocess.CalledProcessError:
                 display_utils.print_warning(
-                    "arc sumbit failed. Starting over."
+                    "arc sumbit failed. Please start over."
                 )
                 print(
                     f"The command ran: {' '.join(arc_args)}"
@@ -211,11 +211,63 @@ def show(base: str = option_base):
     commits = list(repo.iter_commits(f"{base}..HEAD"))
     if not commits:
         display_utils.print_warning('No commits in the stack.')
+    else:
+        phab_utils.fetch_matadata_from_commits(*commits)
     for i, commit in enumerate(commits):
         print(('| ' if i > 0 else '↑ ') + display_utils.commit_summary(commit, short=False))
     display_utils.print_base(base, repo.commit(f"{base}"))
 
 
+@app.command()
+def land(base: str = option_base, bypass_accepted_check: bool = False):
+    """
+    Lands the stack. This command does prechecks to ensure the land is successful.
+    """
+    _precheck(base)
+    repo = Repo(REPO_PATH)
+    commits = list(repo.iter_commits(f"{base}..HEAD"))
+    if not phab_utils.are_commits_all_accepted(*commits) and not bypass_accepted_check:
+        display_utils.print_error("All the diffs must be accepted before you can land.")
+        exit(0)
+    print("Before landing, this script needs to pull and rebase.")
+    print("Right now, Stackler only supports landing onto the git upstream, "
+          + "so the rebase command about to run is `git pull --rebase`. "
+          + "You could run into merge conflicts.'")
+    if not click.confirm('Continue?', default=True):
+        display_utils.print_error('Aborted.')
+        sys.exit(1)
+    else:
+        print('Starting pulling and rebasing.')
+
+    try:
+        subprocess.run(['git', 'pull', '--rebase'], check=True)
+    except subprocess.CalledProcessError:
+        display_utils.print_warning(
+            'Looks like something hit an error. Mostly likely a merge conflict.')
+        print('If that\'s the case, You may resolve it and try again, starting with `git status`.')
+        sys.exit(1)
+
+    current_branch = repo.active_branch
+    print('Starting landing.')
+    arc_args = ['arc', 'land']
+    try:
+        subprocess.run(arc_args, check=True)
+    except subprocess.CalledProcessError:
+        display_utils.print_warning(
+            "arc land failed. Please start over."
+        )
+        print(
+            f"The command ran: {' '.join(arc_args)}"
+        )
+        sys.exit(1)
+
+    # if landing a branchless stack, the repo is left detached, this hack resets it
+    try:
+        repo.active_branch
+    except TypeError:
+        repo.git.checkout(current_branch)
+
+
 def _precheck(base: str):
     """
     Exits the command if precheck fails.
